@@ -33,6 +33,7 @@ from giza.operations.clean import clean
 from giza.operations.sphinx import sphinx
 from giza.operations.deploy import deploy, push
 from giza.operations.quickstart import make_project
+
 def get_base_parser():
     parser = argh.ArghParser()
     parser.add_argument('--level', '-l',
@@ -59,6 +60,7 @@ def main():
         giza.operations.git.apply_patch,
         giza.operations.git.pull_rebase,
         giza.operations.git.cherry_pick,
+        giza.operations.git.merge,
     ]
     argh.add_commands(parser, git_commands, namespace='git')
 
@@ -73,6 +75,7 @@ def main():
         giza.operations.generate.tables,
         giza.operations.generate.toc,
         giza.operations.generate.examples,
+        giza.operations.generate.redirects
     ]
     argh.add_commands(parser, generate_commands, namespace='generate')
 
@@ -105,6 +108,7 @@ def main():
             giza.operations.translate.translate_po,
             giza.operations.translate.translate_text_doc,
             giza.operations.translate.flip_text,
+            giza.operations.translate.auto_approve_obvious_po,
     ]
     argh.add_commands(parser, translate_commands, namespace='translate')
 
