@@ -17,39 +17,138 @@ import logging
 
 logger = logging.getLogger('giza.content.primer')
 
-from giza.serialization import ingest_yaml_list
-from giza.files import copy_if_needed, copy_always, expand_tree, verbose_remove
-
-from giza.transformation import post_process_tasks, truncate_file, append_to_file
+from giza.tools.files import copy_if_needed, copy_always, expand_tree, verbose_remove
+from giza.tools.serialization import ingest_yaml_list
+from giza.tools.transformation import post_process_tasks, truncate_file, append_to_file
 
 def get_migration_specifications(conf):
     return [ fn for fn in expand_tree(os.path.join(conf.paths.projectroot,
                                                    conf.paths.builddata))
-             if conf.project.name in fn and 'migrations' in fn ]
+             if  conf.project.name in os.path.basename(fn) and 'migrations' in fn ]
+
+def directory_expansion(source_path, page, conf):
+    new_page = { 'sources': expand_tree(source_path, None)}
+    del page['source']
+
+    if 'source_dir' in page:
+        new_page['source_dir'] = page['source_dir']
+
+    pages = []
+
+    for p in convert_multi_source(new_page):
+        p.update(page)
+        p['target'] = os.path.join(conf.paths.projectroot,
+                                   conf.paths.source,
+                                   p['target'],
+                                   p['source'][len(source_path)+1:])
+
+        pages.append(p)
+
+
+    return pages
 
 def convert_multi_source(page):
-    if 'source_dir' in page:
-        return [ { 'source': source, 'source_dir': page['source_dir'] }
-                 for source in page['sources'] ]
-    else:
-        return [ { 'source': source }
-                 for source in page['sources'] ]
+    pages = [ { 'source': source }
+              for source in page['sources'] ]
+
+    for k in ('source', 'sources'):
+        if k in page:
+            del page[k]
+
+    r = []
+    for p in pages:
+        p.update(page)
+        r.append(p)
+
+    return r
+
+
+########## Path Normalization Helper Functions
 
 def fix_migration_paths(page):
     if 'target' not in page:
         page['target'] = page['source']
 
-    if page['target'].endswith('.txt'):
+    if 'override' in page:
+        should_override = page['override']
+    else:
+        should_override = False
+
+    if page['target'].endswith('.txt') and should_override is True:
         msg = '({0}) imported files cannot end with ".txt", changing to ".rst"'
         logger.warning(msg.format(page['source']))
         page['target'] = page['target'].replace('.txt', '.rst')
 
+    return page
+
+def trim_leading_slash_from_pages(page):
     for field  in ['source', 'target']:
         if page[field].startswith('/'):
             page[field] = page[field][1:]
 
     return page
 
+def resolve_page_path(page, conf):
+    if page['target'].startswith('/'):
+        fq_target = page['target']
+    else:
+        fq_target = os.path.join(conf.paths.projectroot, conf.paths.source, page['target'])
+
+    if page['source'].startswith('/'):
+        fq_source = page['source']
+    elif 'source_dir' in page:
+        fq_source = os.path.abspath(os.path.join(conf.paths.projectroot, page['source_dir'], page['source']))
+    else:
+        fq_source = os.path.abspath(os.path.join(conf.paths.projectroot, '..', 'source', page['source']))
+
+    return fq_target, fq_source
+
+########## Main Migration Operations and Task Generator
+
+def primer_migration_tasks(conf, app):
+    "Migrates all manual files to primer according to the spec. As needed."
+
+    migration_paths = get_migration_specifications(conf)
+
+    if len(migration_paths) == 0:
+        return False
+    else:
+        migrations = ingest_yaml_list(*migration_paths)
+
+        munge_jobs = []
+        for page in migrations:
+            if 'sources' in page:
+                migrations.extend(convert_multi_source(page))
+                continue
+
+            page = fix_migration_paths(page)
+            fq_target, fq_source = resolve_page_path(page, conf)
+
+            if page['source'].endswith('/'):
+                migrations.extend(directory_expansion(fq_source, page, conf))
+                continue
+
+            page = trim_leading_slash_from_pages(page)
+            prev = build_migration_task(fq_target, fq_source, app)
+
+            if 'truncate' in page:
+                build_truncate_task(page['truncate'], fq_target, app)
+
+            if 'transform' in page:
+                prev.job = copy_always
+                munge_jobs.append(build_transform_task(page['transform'], fq_target))
+
+            if 'append' in page:
+                prev.job = copy_always
+                build_append_task(page, fq_target, migration_paths, app)
+
+        post_process_tasks(app=app, tasks=munge_jobs)
+        msg = 'added {0} migration jobs'.format(len(migrations))
+
+        logger.info(msg)
+
+        return True
+
 def clean(conf):
     "Removes all migrated primer files according to the current spec."
 
@@ -69,49 +168,7 @@ def clean(conf):
     map(verbose_remove, targets)
     logger.info('clean: removed {0} files'.format(len(targets)))
 
-def primer_migration_tasks(conf, app):
-    "Migrates all manual files to primer according to the spec. As needed."
-
-    migration_paths = get_migration_specifications(conf)
-
-    if len(migration_paths) == 0:
-        return False
-    else:
-        migrations = ingest_yaml_list(*migration_paths)
-
-        munge_jobs = []
-        for page in migrations:
-            if 'sources' in page:
-                migrations.extend(convert_multi_source(page))
-                continue
-
-            page = fix_migration_paths(page)
-
-            fq_target = os.path.join(conf.paths.projectroot, conf.paths.source, page['target'])
-            if 'source_dir' in page:
-                fq_source = os.path.abspath(os.path.join(conf.paths.projectroot, page['source_dir'], page['source']))
-            else:
-                fq_source = os.path.abspath(os.path.join(conf.paths.projectroot, '..', 'source', page['source']))
-
-            prev = build_migration_task(fq_target, fq_source, app)
-
-            if 'truncate' in page:
-                build_truncate_task(page['truncate'], fq_target, app)
-
-            if 'transform' in page:
-                prev.job = copy_always
-                munge_jobs.append(build_transform_task(page['transform'], fq_target, app))
-
-            if 'append' in page:
-                prev.job = copy_always
-                build_append_task(page, fq_target, migration_paths, app)
-
-        post_process_tasks(app=app, tasks=munge_jobs)
-        msg = 'added {0} migration jobs'.format(len(migrations))
-
-        logger.info(msg)
-
-        return True
+########## Task Creators
 
 def build_migration_task(target, source, app):
     task = app.add('task')
@@ -121,7 +178,7 @@ def build_migration_task(target, source, app):
 
     return task
 
-def build_transform_task(transform, target, app):
+def build_transform_task(transform, target):
     return {
         'file': target,
         'type': 'primer-processing',
