@@ -4,7 +4,7 @@ import argh
 import itertools
 
 from giza.config.helper import fetch_config
-from giza.app import BuildApp
+from giza.core.app import BuildApp
 
 logger = logging.getLogger('giza.operations.sphinx')
 
@@ -25,6 +25,7 @@ from giza.content.steps import steps_tasks
 from giza.content.dependencies import refresh_dependency_tasks
 from giza.content.sphinx import sphinx_tasks, output_sphinx_stream, finalize_sphinx_build
 from giza.content.primer import primer_migration_tasks
+from giza.content.redirects import redirect_tasks
 
 from giza.config.sphinx_config import render_sconf
 
@@ -114,6 +115,7 @@ def build_prep_tasks(conf, app):
     hash_tasks(conf, app)
 
 def build_content_generation_tasks(conf, app):
+    redirect_tasks(conf, app)
     steps_tasks(conf, app.add('app'))
     toc_tasks(conf, app)
     example_tasks(conf, app)
